@@ -28,6 +28,9 @@ class InvalidPacoBucket(Exception):
 class InvalidAWSResourceName(Exception):
     title = "Name is not valid to use as an AWS Resource name"
 
+class InvalidAlarmConfiguration(Exception):
+    title = "Alarm configuration is not valid"
+
 class TroposphereConversionError(Exception):
     title = "Troposphere Conversion Error"
 
@@ -35,4 +38,10 @@ class InvalidModelObject(Exception):
     title = "Invalid Model Object"
 
 class InvalidLocalPath(Exception):
-    title = "Local path location does not exist"
\ No newline at end of file
+    title = "Local path location does not exist"
+
+class AlarmDescriptionExtensionConflict(Exception):
+    title = "AlarmDescription extension conflict"
+
+class LoaderRegistrationError(Exception):
+    title = "Loader Registration conflict"
