@@ -2,3 +2,5 @@
 EXTEND_BASE_MODEL_HOOKS = []
 CW_ALARM_ACTIONS_HOOK = None
 CW_ALARM_HOOKS = []
+CW_ALARM_DESCRIPTION_HOOK = None
+CODESTAR_NOTIFICATION_RULE_HOOK = None
\ No newline at end of file
